==> qtjambi-qt3drender-6.5.7-sources.jar: io/qt/qt3d/render/QDepthRange.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enables remapping depth values written into the depth buffer</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html">Qt3DRender::QDepthRange</a></code></p>
 */
public class QDepthRange extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDepthRange.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr/>farValueChanged(double)</a></code></p>
     */
    @QtPropertyNotify(name="farValue")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> farValueChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr/>nearValueChanged(double)</a></code></p>
     */
    @QtPropertyNotify(name="nearValue")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> nearValueChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QDepthRange::<wbr/>QDepthRange(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QDepthRange(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDepthRange instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr/>farValue()const</a></code></p>
     */
    @QtPropertyReader(name="farValue")
    @QtUninvokable
    public final double farValue(){
        return farValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double farValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr/>nearValue()const</a></code></p>
     */
    @QtPropertyReader(name="nearValue")
    @QtUninvokable
    public final double nearValue(){
        return nearValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double nearValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr/>setFarValue(double)</a></code></p>
     */
    @QtPropertyWriter(name="farValue")
    public final void setFarValue(double value){
        setFarValue_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setFarValue_native_double(long __this__nativeId, double value);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr/>setNearValue(double)</a></code></p>
     */
    @QtPropertyWriter(name="nearValue")
    public final void setNearValue(double value){
        setNearValue_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setNearValue_native_double(long __this__nativeId, double value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDepthRange(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QDepthRange(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QDepthRange instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QDepthRange(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDepthRange() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #farValue()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getFarValue() {
        return farValue();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #nearValue()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getNearValue() {
        return nearValue();
    }
}

==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QDepthRange.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enables remapping depth values written into the depth buffer</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html">Qt3DRender::QDepthRange</a></code></p>
 */
public class QDepthRange extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDepthRange.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr>farValueChanged(double)</a></code></p>
     */
    @QtPropertyNotify(name="farValue")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> farValueChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr>nearValueChanged(double)</a></code></p>
     */
    @QtPropertyNotify(name="nearValue")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Double> nearValueChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QDepthRange::<wbr>QDepthRange(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QDepthRange(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDepthRange instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr>farValue()const</a></code></p>
     */
    @QtPropertyReader(name="farValue")
    @QtUninvokable
    public final double farValue(){
        return farValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double farValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr>nearValue()const</a></code></p>
     */
    @QtPropertyReader(name="nearValue")
    @QtUninvokable
    public final double nearValue(){
        return nearValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double nearValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#farValue-prop">Qt3DRender::QDepthRange::<wbr>setFarValue(double)</a></code></p>
     */
    @QtPropertyWriter(name="farValue")
    public final void setFarValue(double value){
        setFarValue_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setFarValue_native_double(long __this__nativeId, double value);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qdepthrange.html#nearValue-prop">Qt3DRender::QDepthRange::<wbr>setNearValue(double)</a></code></p>
     */
    @QtPropertyWriter(name="nearValue")
    public final void setNearValue(double value){
        setNearValue_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    private native void setNearValue_native_double(long __this__nativeId, double value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDepthRange(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QDepthRange(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QDepthRange instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QDepthRange(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDepthRange() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #farValue()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getFarValue() {
        return farValue();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #nearValue()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final double getNearValue() {
        return nearValue();
    }
}
